@@ -2,11 +2,10 @@
 import click
 from loguru import logger as log
 
-from AgentService.agent import Agent
-from AgentService.types.agent_tool import AgentTool
+from AgentService.agent import Agent, AgentTool
 from AgentService.config import Config
-from AgentService.db import Db
 from AgentService.app import start_app
+from AgentService.types import setup_database
 
 
 @click.group()
@@ -37,7 +36,4 @@ def start_project():
     )
     config.set_agent(agent)
 
-    db = Db()
-    db.connect(config.db_name, config.db_uri)
-
     start_app()
