@@ -1,5 +1,5 @@
 
-from AgentService.dtypes.message.message import Tool
+from AgentService.types import Tool
 from typing import Any
 
 
